==> open-xchange-osgi_7.10.5.orig.tar.bz2: open-xchange-osgi-7.10.5/com.openexchange.hazelcast.ssl/src/com/openexchange/hazelcast/ssl/HazelcastSSLContextFactoryProvider.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.hazelcast.ssl;

import com.openexchange.osgi.annotation.SingletonService;

/**
 * {@link HazelcastSSLContextFactoryProvider} - Provides the implementation of <code>com.hazelcast.nio.ssl.SSLContextFactory</code>.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.10.6
 */
@SingletonService
public interface HazelcastSSLContextFactoryProvider {

    /**
     * Creates a new instance of <code>com.hazelcast.nio.ssl.SSLContextFactory</code>.
     *
     * @return The new instance of <code>com.hazelcast.nio.ssl.SSLContextFactory</code>
     */
    Object newSSLContextFactory();
}

==> open-xchange-osgi_7.10.6.orig.tar.bz2: open-xchange-osgi-7.10.6/com.openexchange.hazelcast.ssl/src/com/openexchange/hazelcast/ssl/HazelcastSSLContextFactoryProvider.java <==
/*
 * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.hazelcast.ssl;

import com.openexchange.osgi.annotation.SingletonService;

/**
 * {@link HazelcastSSLContextFactoryProvider} - Provides the implementation of <code>com.hazelcast.nio.ssl.SSLContextFactory</code>.
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.10.6
 */
@SingletonService
public interface HazelcastSSLContextFactoryProvider {

    /**
     * Creates a new instance of <code>com.hazelcast.nio.ssl.SSLContextFactory</code>.
     * <p>
     * Obtain an instance with:
     * <pre>
     *   HazelcastSSLContextFactoryProvider factoryProvider = getService(HazelcastSSLContextFactoryProvider.class);
     *   SSLContextFactory factory = (SSLContextFactory) factoryProvider.newSSLContextFactory();
     *   ...
     * </pre>
     *
     * @return The new instance of <code>com.hazelcast.nio.ssl.SSLContextFactory</code>
     */
    Object newSSLContextFactory();
}
